==> skeet-0.36.3.tgz: package/src/templates/init/skeet-cloud.config.ts <==
import { getHomeIp } from '@/cli'

export const skeetCloudConfigGen = async (appName: string) => {
  const filePath = `${appName}/skeet-cloud.config.json`
  const homeIp = await getHomeIp()
  const body = `{
  "api": {
    "appName": "${appName}",
    "projectId": "${appName}",
    "region": "europe-west4",
    "hasLoadBalancer": false,
    "cloudRun": {
      "name": "skeet-${appName}-api",
      "url": "",
      "cpu": 1,
      "maxConcurrency": 80,
      "maxInstances": 100,
      "minInstances": 0,
      "memory": "4Gi"
    },
    "db": {
      "databaseVersion": "POSTGRES_14",
      "cpu": 1,
      "memory": "3840MiB",
      "storageSize": 10,
      "whiteList": ""
    }
  },
  "workers": [],
  "taskQueues": [],
  "cloudArmor": [
    {
      "securityPolicyName": "skeet-${appName}-armor",
      "rules": [
        {
          "priority": "10",
          "description": "Allow Your Home IP addresses",
          "options": {
            "src-ip-ranges": "${homeIp}",
            "action": "allow"
          }
        },
        {
          "priority": "20",
          "description": "Allow Google Cloud Task",
          "options": {
            "expression": "has(request.headers['User-Agent']) && request.headers['User-Agent'].contains('Google-Cloud-Tasks')",
            "action": "allow"
          }
        },
        {
          "priority": "21",
          "description": "Allow Google Cloud Scheduler",
          "options": {
            "expression": "has(request.headers['User-Agent']) && request.headers['User-Agent'].contains('Google-Cloud-Scheduler')",
            "action": "allow"
          }
        },
        {
          "priority": "20",
          "description": "Allow host",
          "options": {
            "action": "allow",
            "expression": "request.headers['host'].lower().contains('http://localhost:4200')"
          }
        },
        {
          "priority": "100",
          "description": "Defense from SQLi attack",
          "options": {
            "action": "deny-403",
            "expression": "evaluatePreconfiguredExpr('sqli-stable')"
          }
        },
        {
          "priority": "200",
          "description": "Defense from XSS attack",
          "options": {
            "action": "deny-403",
            "expression": "evaluatePreconfiguredExpr('xss-stable')"
          }
        },
        {
          "priority": "300",
          "description": "Defense from NodeJS attack",
          "options": {
            "action": "deny-403",
            "expression": "evaluatePreconfiguredExpr('nodejs-v33-stable')"
          }
        },
        {
          "priority": "1000",
          "description": "ban 300sec if exceed 50 access in 60sec",
          "options": {
            "action": "rate-based-ban",
            "src-ip-ranges": "*",
            "rate-limit-threshold-count": "50",
            "rate-limit-threshold-interval-sec": "60",
            "ban-duration-sec": "300",
            "conform-action": "allow",
            "exceed-action": "deny-429",
            "enforce-on-key": "IP"
          }
        },
        {
          "priority": "2147483647",
          "description": "Deny All IP addresses",
          "options": {
            "action": "deny-403"
          }
        }
      ]
    }
  ]
}  
`
  return {
    filePath,
    body,
  }
}

==> skeet-0.36.4.tgz: package/src/templates/init/skeet-cloud.config.ts <==
import { getHomeIp } from '@/cli'

export const skeetCloudConfigGen = async (appName: string) => {
  const filePath = `${appName}/skeet-cloud.config.json`
  const homeIp = await getHomeIp()
  const body = `{
  "api": {
    "appName": "${appName}",
    "projectId": "${appName}",
    "region": "europe-west4",
    "hasLoadBalancer": false,
    "cloudRun": {
      "name": "skeet-${appName}-api",
      "url": "",
      "cpu": 1,
      "maxConcurrency": 80,
      "maxInstances": 100,
      "minInstances": 0,
      "memory": "4Gi"
    },
    "db": {
      "databaseVersion": "POSTGRES_14",
      "cpu": 1,
      "memory": "3840MiB",
      "storageSize": 10,
      "whiteList": ""
    }
  },
  "workers": [],
  "taskQueues": [],
  "cloudArmor": [
    {
      "securityPolicyName": "skeet-${appName}-armor",
      "rules": [
        {
          "priority": "10",
          "description": "Allow Your Home IP addresses",
          "options": {
            "src-ip-ranges": "${homeIp}",
            "action": "allow"
          }
        },
        {
          "priority": "20",
          "description": "Allow host",
          "options": {
            "action": "allow",
            "expression": "has(request.headers['referer']) && request.headers['referer'] == \"http://localhost:4000/\""
          }
        },
        {
          "priority": "100",
          "description": "Defense from SQLi attack",
          "options": {
            "action": "deny-403",
            "expression": "evaluatePreconfiguredExpr('sqli-stable')"
          }
        },
        {
          "priority": "200",
          "description": "Defense from XSS attack",
          "options": {
            "action": "deny-403",
            "expression": "evaluatePreconfiguredExpr('xss-stable')"
          }
        },
        {
          "priority": "300",
          "description": "Defense from NodeJS attack",
          "options": {
            "action": "deny-403",
            "expression": "evaluatePreconfiguredExpr('nodejs-v33-stable')"
          }
        },
        {
          "priority": "2147483647",
          "description": "Deny All IP addresses",
          "options": {
            "action": "deny-403"
          }
        }
      ]
    }
  ]
}  
`
  return {
    filePath,
    body,
  }
}
